@@ -6,7 +6,7 @@ describe ChildProcess::AbstractIO do
   it "inherits the parent's IO streams" do
     io.inherit!
 
-    io.stdout.should == STDOUT
-    io.stderr.should == STDERR
+    expect(io.stdout).to eq STDOUT
+    expect(io.stderr).to eq STDERR
   end
 end
